# Table of Contents

- [sbom-discovery-from-build-artifacts](<./sbom-discovery-from-build-artifacts.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SBOM Discovery from Build Artifacts](<./SBOM-Discovery-from-Build-Artifacts.md>)
  - [Prerequisites](<./SBOM-Discovery-from-Build-Artifacts/Prerequisites.md>)
  - [Configuration](<./SBOM-Discovery-from-Build-Artifacts/Configuration.md>)
  - [SBOM Naming Convention](<./SBOM-Discovery-from-Build-Artifacts/SBOM-Naming-Convention.md>)
  - [Branches](<./SBOM-Discovery-from-Build-Artifacts/Branches.md>)
  - [GitHub App Permissions](<./SBOM-Discovery-from-Build-Artifacts/GitHub-App-Permissions.md>)
  - [Example](<./SBOM-Discovery-from-Build-Artifacts/Example.md>)
